@@ -21,7 +21,7 @@ our $DEBUG;
 our $VERIFY_PREFIX = "use Types::Common -types, -sigs;";
 
 BEGIN {
-  our $VERSION = qv(8.5.1);
+  our $VERSION = qv(8.5.2);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -194,8 +194,8 @@ sub import {
   $DEBUG                         = $_[1];
   our $VERIFY_PREFIX = $_[2] if $DEBUG eq "verify" and @_ == 3;
   local $@;
-  my $pkg = caller;
-  eval {"package $pkg; use class; use types"}; # enable perl type system
+  my $pkg                        = caller;
+  eval "package $pkg; use types; use class"; # enable perl type system
   die $@ if $@;
   filter_add(bless []);
 }
